#ifndef WCME_CONFIG_H
#define WCME_CONFIG_H

#ifdef __VMS
#include "vms.h"

/* differentiate between purely __VMS code (changes) and wCME code */
#define WCME_IDIOM

#define WCME_DBG_ALL 0

#if WCME_DBG_ALL
#define WCME_DBG_ACCTPROC    /* acctproc.c */
#define WCME_DBG_CERTPROC    /* certproc.c */
#define WCME_DBG_CHNGPROC    /* chngproc.c */
#define WCME_DBG_DNSPROC     /* dnsproc.c */
#define WCME_DBG_FILEPROC    /* fileproc.c */
#define WCME_DBG_HTTP        /* http.c */
#define WCME_DBG_KEYPROC     /* keyproc.c */
#define WCME_DBG_MAIN        /* main.c */
#define WCME_DBG_NETPROC     /* netproc.c */
#define WCME_DBG_REVOKEPROC  /* revokeproc.c */
#define WCME_DBG_UTIL        /* util.c */
#define WCME_DBG_VMS         /* vms.c */
#else
/* reduce "__" to "_" to enable individual debug statements */
#define WCME_DBG__ACCTPROC    /* acctproc.c */
#define WCME_DBG__CERTPROC    /* certproc.c */
#define WCME_DBG__CHNGPROC    /* chngproc.c */
#define WCME_DBG__DNSPROC     /* dnsproc.c */
#define WCME_DBG__FILEPROC    /* fileproc.c */
#define WCME_DBG__HTTP        /* http.c */
#define WCME_DBG__KEYPROC     /* keyproc.c */
#define WCME_DBG__MAIN        /* main.c */
#define WCME_DBG__NETPROC     /* netproc.c */
#define WCME_DBG__REVOKEPROC  /* revokeproc.c */
#define WCME_DBG__UTIL        /* util.c */
#define WCME_DBG__VMS         /* vms.c */
#endif

#define URL_REAL_CA "https://acme-v01.api.letsencrypt.org/directory"
#define URL_STAGE_CA "https://acme-staging.api.letsencrypt.org/directory"

#define SSL_DIR "/wcme_root/ssl"
#define SSL_PRIV_DIR "/wcme_root/priv"
#define ETC_DIR "/wcme_root/etc"
#define WWW_DIR "/wcme_root/www"

#define ACCT_KEY "/wcme_root/etc/privkey.pem"
#define PRIV_KEY "/wcme_root/priv/privkey.pem"
#define CONF_FILE "not-used-in-WCME"

struct authority_c {
//        TAILQ_ENTRY(authority_c)         entry;
        char                               *name;
        char                               *api;
        char                               *account;
};

#endif /* __VMS */

/*
 * If your system doesn't use "nobody" as a privilege separated user,
 * then change it here or in the GNUmakefile.
 */
#ifndef NOBODY_USER
# define NOBODY_USER "nobody"
#endif

/*
 * You can define this if your system has its /var/empty elsewhere.
 */
/* #define PATH_VAR_EMPTY "/var/empty" */

/*
 * Require libbsd's stdlib.h for arc4random() etc.
 * Require <grp.h> for setgroups().
 */
#ifdef __linux__
# define _GNU_SOURCE
# ifndef MUSL_LIBC
#  include <bsd/stdlib.h>
#  include <bsd/string.h>
# else
#  include <errno.h>
#  include <unistd.h>
#  define getprogname() (program_invocation_short_name)
# endif
# include <grp.h>
#endif

/*
 * Apple and NetBSD haven't got these.
 */
#if defined(__APPLE__) || defined(__NetBSD__)
# include <unistd.h>
int	setresgid(gid_t, gid_t, gid_t);
int	setresuid(gid_t, gid_t, gid_t);
#endif

/*
 * Apple usually gets their libressl from homebrew.
 * It'd be put in here, but let it be overriden.
 */
#if defined(__APPLE__)
# ifndef DEFAULT_CA_FILE
#  define DEFAULT_CA_FILE "/usr/local/etc/libressl/cert.pem"
# endif
#endif

/*
 * FreeBSD goop.
 */
#ifdef __FreeBSD__
#include <sys/socket.h>
#include <sys/types.h>
#include <arpa/inet.h>
#include <netinet/in.h>
#include <resolv.h>
#endif

#if !defined(__BEGIN_DECLS)
#  ifdef __cplusplus
#  define       __BEGIN_DECLS           extern "C" {
#  else
#  define       __BEGIN_DECLS
#  endif
#endif
#if !defined(__END_DECLS)
#  ifdef __cplusplus
#  define       __END_DECLS             }
#  else
#  define       __END_DECLS
#  endif
#endif

#endif /* WCME_CONFIG_H */
